"use client";

import useFetch from "@/hooks/useFetch";
import { useEffect } from "react";
import { useSearchParams, useRouter } from "next/navigation";
import { useToast } from "@/contexts/ToastContext";
import { useTranslations } from "next-intl";
import useUser from "@/hooks/useUser";

export default function PaypalCallback() {
    const searchParams = useSearchParams();
    const router = useRouter();
    const paymentId = searchParams.get("paymentId");
    const token = searchParams.get("token");
    const PayerID = searchParams.get("PayerID");
    const t = useTranslations("pricing");
    const { addToastSuccess } = useToast();
    const { updateUser } = useUser();
    const {
        fetchData: executePayment,
        loading: paymentLoading,
        data: paymentData,
    } = useFetch({
        url: "/api/paypal/execute/",
        method: "POST",
    });

    useEffect(() => {
        if (paymentId && token && PayerID) {
            executePayment({
                paymentId,
                PayerID,
            })
                .then(() => {
                    addToastSuccess(t("PaymentSuccess"));
                    // 删除URL上的参数
                })
                .finally(() => {
                    const newUrl = window.location.pathname;
                    window.history.replaceState(null, "", newUrl);
                    updateUser();
                });
        }
    }, [paymentId, token, PayerID]);

    return null;
}
