import { GetPost, GetRandomPosts } from "@/apis/auth";
import PageRemark from "@/ui/page/page-remark";
import { Metadata } from "next";
import { getLocale } from "next-intl/server";
import Image from "next/image";
import Link from "next/link";

export const metadata: Metadata = {
    title: "",
    keywords: "",
};

export default async function Article({ params }) {
    const postID = params.id;
    const locale = await getLocale();
    let postContent = "";
    let title = "";
    let keyword = "";
    let time = "";
    let imgUrl = "";
    let randomPosts: any = [];

    try {
        const data = await GetPost(postID, locale);
        if (data.code === 200) {
            postContent = data.data.content;
            title = data.data.title;
            keyword = data.data.keywords;
            time = data.data.published_at;
            imgUrl = data.data.image_url;
            console.log("imgUrl", imgUrl);
            metadata.title = title;
            metadata.keywords = keyword;
        }

        // 获取随机文章推荐
        const randomData = await GetRandomPosts(); // 假设返回3篇随机文章
        if (randomData.code === 200) {
            randomPosts = randomData.data.articles;
        }
    } catch {}

    return (
        <>
            <article className="rounded-lg px-4 sm:px-6 md:px-8 border border-[#252629] w-full bg-[#15171a] text-white ">
                <div className="relative z-10 mx-auto py-12 lg:py-24">
                    <div className="space-y-4 mb-14">
                        <h2 className='font-["Euclid_Circular_A"] text-3xl lg:text-4xl xl:text-5xl text-center'>
                            {title}
                        </h2>
                    </div>
                    {/* 
                    <Image
                        src={imgUrl}
                        alt={keyword}
                        width={1920}
                        height={1080}
                        className="w-[90%] lg:w-[85%] xl:w-[75%] mx-auto my-4"
                    /> */}

                    <article className="w-[90%] lg:w-[85%] xl:w-[75%] mx-auto space-y-6">
                        <section>
                            <div
                                className="whitespace-pre-line indent-[2em] leading-relaxed text-lg text-gray-200"
                                dangerouslySetInnerHTML={{
                                    __html: postContent.replace(
                                        /<p>/g,
                                        '<p class="mb-4">'
                                    ),
                                }}
                            ></div>
                        </section>
                    </article>
                    <div className="w-[90%] lg:w-[85%] xl:w-[75%] mx-auto mt-10 text-gray-400">
                        <div>
                            {keyword.split(",").map((item, index) => {
                                return (
                                    <Link
                                        href={`/article-list/1?tag=${item}`}
                                        key={index}
                                        className=" underline mr-4"
                                    >
                                        #{item}
                                    </Link>
                                );
                            })}
                        </div>
                        <div>{time}</div>
                    </div>
                    <PageRemark />

                    {/* 随机文章推荐 */}
                    <div className="w-[90%] lg:w-[85%] xl:w-[75%] mx-auto mt-14">
                        <h3 className="text-2xl font-bold mb-6 text-white">
                            {locale === "en" ? "Related Articles" : "相关文章"}
                        </h3>
                        <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-6">
                            {randomPosts.map((item, index) => (
                                <div
                                    className="bg-[#15171a] rounded-lg overflow-hidden shadow-lg"
                                    key={index}
                                >
                                    <Link href={`/article/${item.id}`}>
                                        <Image
                                            src={item["image_url"]}
                                            width={1920}
                                            height={1080}
                                            alt={item["keywords"]}
                                            className="w-full h-48 object-cover"
                                        />
                                    </Link>

                                    <div className="p-6">
                                        <Link
                                            href={`/article/${item.id}`}
                                            className="text-white hover:text-secondary hover:underline"
                                        >
                                            <h2 className="text-xl font-bold mb-2">
                                                {item[`${locale}_title`]}
                                            </h2>
                                        </Link>
                                        <p className="text-gray-400 text-sm mb-4">
                                            {new Date(
                                                item["published_at"]
                                            ).toLocaleDateString(locale, {
                                                year: "numeric",
                                                month: "long",
                                                day: "numeric",
                                            })}
                                        </p>
                                        <p className="text-gray-300 mb-6">
                                            {item[`${locale}_keywords`].map(
                                                (kitem, kindex) => (
                                                    <Link
                                                        href={`/article-list/1?tag=${kitem}`}
                                                        key={kindex}
                                                        className="mr-2 text-sm hover:underline hover:text-secondary"
                                                    >
                                                        #{kitem}
                                                    </Link>
                                                )
                                            )}
                                        </p>
                                        <Link
                                            href={`/article/${item.id}`}
                                            className="text-secondary hover:underline"
                                        >
                                            Read More
                                        </Link>
                                    </div>
                                </div>
                            ))}
                        </div>
                    </div>
                </div>
            </article>
        </>
    );
}
