"use client";
import PaymentDialog from "@/components/PaymentDialog";
import useFetch from "@/hooks/useFetch";
import useLoadingStore from "@/store/loadingStore";
import classNames from "classnames";
import Link from "next/link";
import { useEffect, useState } from "react";
import { useTranslations } from "next-intl";
export default function Page() {
    const t = useTranslations("pricing"); // 使用翻译
    const { fetchData: GetPricing, data: pricingData } = useFetch({
        url: "/api/plans/",
        method: "GET",
    });
    const isMobile = useIsMobile();
    useEffect(() => {
        GetPricing().then((res) => {
            console.log("pricing:", res);
        });
    }, []);
    let alipayUrl = "/api/alipay/create_order/";
    if (isMobile) {
        alipayUrl = "api/alipay/create_h5_order/";
    }
    const {
        fetchData: createPayPalOrder,
        loading: payPalLoading,
        data: payPalData,
    } = useFetch({
        url: "/api/paypal/create/",
        method: "POST",
    });
    const showLoading = useLoadingStore((state) => state.showLoading);
    const hideLoading = useLoadingStore((state) => state.hideLoading);
    const {
        fetchData: createAlipayOrder,
        loading: alipayLoading,
        data: alipayData,
    } = useFetch({
        url: alipayUrl,
        method: "POST",
    });

    const {
        fetchData: createAlipayH5Order,
        loading: alipayH5Loading,
        data: alipayH5Data,
    } = useFetch({
        url: "/api/alipay/create_h5_order/",
        method: "POST",
    });

    const [isDialogOpen, setDialogOpen] = useState(false);
    const [selectedPlan, setSelectedPlan] = useState({
        id: null,
        title: "",
        price: null,
    });

    const openDialog = () => {
        setDialogOpen(true);
    };
    const handlePay = (platform) => {
        const { id, title, price } = selectedPlan;
        if (!id || !title || !price) return;
        if (platform === "paypal") {
            showLoading();
            createPayPalOrder({ plan_id: id, payment_method: "paypal" })
                .then((res) => {
                    console.log("paypal res：", res);
                    window.location.href = res.approval_url;
                })
                .finally(() => {
                    hideLoading();
                });
        } else {
            showLoading();
            createAlipayOrder({ id, title, price })
                .then((res) => {
                    console.log("Alipay res：", res);
                    window.location.href = res.alipay_url;
                })
                .finally(() => {
                    hideLoading();
                });
        }
    };
    return (
        <>
            <article className="rounded-lg px-4 sm:px-6 md:px-8 border border-[#252629] w-full bg-[#15171a]">
                <div className="w-full relative border-x border-[#353e3b]">
                    <div className="absolute z-0 w-full h-full grid lg:grid-cols-2 gap-8 items-center">
                        <section className="-z-0 absolute w-full h-full col-span-2 grid grid-cols-2 place-content-between">
                            <div className="bg-[#4BDE81] rounded-full w-1 h-1 my-8 outline outline-8 outline-[#15171A] -mx-[2.5px] "></div>
                            <div className="bg-[#4BDE81] rounded-full w-1 h-1 my-8 outline outline-8 outline-[#15171A] -mx-[2px] place-self-end"></div>
                            <div className="bg-[#4BDE81] rounded-full w-1 h-1 my-8 outline outline-8 outline-[#15171A] -mx-[2.5px] "></div>
                            <div className="bg-[#4BDE81] rounded-full w-1 h-1 my-8 outline outline-8 outline-[#15171A] -mx-[2px] place-self-end"></div>
                        </section>
                    </div>
                    <div className="relative z-10 mx-auto py-12 lg:py-24">
                        <div className="space-y-4 mb-14">
                            <div className="mx-auto text-green-200 border border-[#c8eed6]/25 shadow-lg shadow-[#4add80]/10 w-fit font-medium text-sm rounded-full bg-gradient-to-b from-[#737b88]/20 to-[#191b1e]/20 p-[1.5px]">
                                <div className="bg-[#15171a]/50 flex items-center space-x-1 py-1 px-2 rounded-full ">
                                    {/* SVG Icon here */}
                                    <span> {t("pricing")}</span>
                                </div>
                            </div>
                            <h2 className='text-white font-["Euclid_Circular_A"] text-3xl lg:text-4xl xl:text-5xl text-center w-11/12 max-w-3xl text-pretty mx-auto'>
                                {t("chooseYourPlan")}
                            </h2>
                            {/* <p className="text-center text-neutral-dark">
                            Get 2 months free when you pay yearly
                        </p> */}
                        </div>
                        <article className="grid grid-cols-1 lg:grid-cols-3 gap-4 items-start justify-start w-[95%] lg:w-[85%] xl:w-[75%] mx-auto">
                            {pricingData &&
                                pricingData.map((plan, index) => (
                                    <section
                                        key={index}
                                        className={classNames(
                                            "relative rounded-xl p-8 border border-white/5 flex flex-col",
                                            {
                                                "bg-[#353e3b]/20":
                                                    plan.is_promotional,
                                            }
                                        )}
                                    >
                                        {plan.is_promotional && (
                                            <small className="text-[#beffd6] absolute top-2 right-2 bg-white/5 font-normal rounded-full px-2 py-1 text-xs ml-auto">
                                                {t("LaunchOffer")}
                                            </small>
                                        )}
                                        <div className="uppercase text-transparent font-medium text-left bg-clip-text bg-gradient-to-b bg-[length:250%_100%] from-white/50 via-white to-white/50">
                                            {t(plan.title)}
                                        </div>
                                        <div className='w-full my-5 mb-2 flex items-end gap-2 text-white font-["Euclid_Circular_A"] text-4xl font-bold'>
                                            <div
                                                className="flex flex-col overflow-hidden"
                                                style={{ height: "1em" }}
                                            >
                                                <span>{`$${plan.price}`}</span>
                                            </div>
                                            {/* <small className="text-neutral-dark text-sm -ml-1.5 font-normal">
                                                /month
                                            </small> */}
                                        </div>
                                        <div className="mt-4 flex flex-col gap-3">
                                            <div className="flex flex-col items-start w-full gap-2.5 py-4 text-neutral-dark border-y border-white/5">
                                                <div className="flex gap-2 items-center">
                                                    {/* SVG Icon here */}
                                                    {t("get")}{" "}
                                                    {plan.credits_per_month}{" "}
                                                    {t("points")}
                                                </div>
                                                <div className="flex gap-2 items-center">
                                                    {t("FastVideoGeneration")}
                                                </div>
                                                <div className="flex gap-2 items-center">
                                                    {t("RichVideoContent")}
                                                </div>
                                            </div>
                                            <div className="z-[0] relative group">
                                                <div
                                                    className={classNames(
                                                        "mt-3 mb-2",
                                                        {
                                                            "btn-tf-primary-container":
                                                                plan.is_promotional,
                                                        }
                                                    )}
                                                >
                                                    <Link
                                                        className={classNames(
                                                            "btn-tf w-full flex items-center justify-center gap-2 transition-all duration-300", // 添加 transition 以使 hover 效果平滑
                                                            {
                                                                "btn-tf-secondary hover:border-secondary hover:text-secondary":
                                                                    !plan.is_promotional,
                                                                "btn-tf-primary  hover:shadow-[0_7px_16.1px_-3px_rgba(75,222,129,.49)]":
                                                                    plan.is_promotional,
                                                            }
                                                        )}
                                                        href="#"
                                                        onClick={() => {
                                                            openDialog();
                                                            setSelectedPlan({
                                                                id: plan.id,
                                                                title: plan.title,
                                                                price: plan.price,
                                                            });
                                                        }}
                                                    >
                                                        {t("SelectPlan")}
                                                    </Link>
                                                </div>
                                            </div>
                                            <div className="mt-2 flex flex-col gap-1 text-neutral-dark text-xs font-medium">
                                                <div className="text-[10px] leading-tight font-normal text-[#6e7176]">
                                                    {t("agree")}
                                                    {/* <Link
                                                        className="font-semibold"
                                                        href="/terms"
                                                    >
                                                        terms
                                                    </Link> */}
                                                </div>
                                            </div>
                                        </div>
                                    </section>
                                ))}
                        </article>
                        <div className="mt-10 w-full flex justify-center items-center">
                            <p className="text-info">
                                {t("SubscriptionsInclude")}
                            </p>
                        </div>
                        <div className="text-center space-y-3 flex flex-col items-center mt-14">
                            <article className="flex items-center flex-col w-full mt-10 space-y-2">
                                <div className="flex flex-col">
                                    <h2 className="text-xl text-center font-semibold text-white">
                                        {t("GenerateVideos")}
                                    </h2>
                                    <p className="text-neutral-dark text-sm text-center sm:text-base">
                                        {t("SaveMoney")}
                                    </p>
                                    <div className="mt-8 flex flex-col justify-center items-center">
                                        <span className="text-gray-300 font-bold">
                                            {t("UsedByCreators")}
                                        </span>
                                    </div>
                                </div>
                                {/* <div className="mt-0 flex flex-col justify-center items-center">
                                    <div className="flex gap-4 flex-col items-center md:flex-row md:items-end ">
                                        <div className="mt-4 flex -space-x-1 children:h-10 children:w-10 children:rounded-full children:object-cover children:ring-2 children:ring-white">
                                        </div>
                                        <div className="text-info text-sm italic">
                                            and 1,000+ others
                                        </div>
                                    </div>
                                </div> */}
                            </article>
                        </div>
                    </div>
                </div>
            </article>
            <PaymentDialog
                open={isDialogOpen}
                setOpen={setDialogOpen}
                onHandlePay={handlePay}
            />
        </>
    );
}
const useIsMobile = () => {
    const [isMobile, setIsMobile] = useState(false);

    useEffect(() => {
        const userAgent =
            typeof window !== "undefined" ? navigator.userAgent : "";
        const mobileRegex =
            /Android|iPhone|iPad|iPod|Opera Mini|IEMobile|WPDesktop/i;
        setIsMobile(mobileRegex.test(userAgent));
    }, []);

    return isMobile;
};
