import type { Metadata } from "next";
import { Suspense } from "react";
import { Inter } from "next/font/google";
import { NextIntlClientProvider } from "next-intl";
import { getLocale, getMessages } from "next-intl/server";
import { GetMetadata } from "@/apis/auth";
import "./globals.scss";
import Loading from "./loading";
import CombinedProviders from "@/contexts/CombinedProviders";
import GoogleAnalytics from "@/components/GoogleAnalytics";

const inter = Inter({ subsets: ["latin"] });

export async function generateMetadata(): Promise<Metadata> {
    const res = await GetMetadata(); // 调用API获取SEO数据
    if (res.code === 200) {
        const seoData = res.data;
        const locale = await getLocale();
        return {
            title: seoData["title_" + locale] || "typeframes",
            description:
                seoData["description_" + locale] || "Generated by typeframes",
            keywords: seoData["keywords_" + locale] || "",
        };
    } else {
        return {
            title: "typeframes",
            description: "Generated by typeframes",
        };
    }
}
async function RootLayout({
    children,
}: Readonly<{
    children: React.ReactNode;
}>) {
    const locale = await getLocale();

    const messages = await getMessages();

    return (
        <html lang={locale}>
            <body className={inter.className}>
                <NextIntlClientProvider messages={messages}>
                    <Suspense fallback={<Loading />}>
                        <CombinedProviders>{children}</CombinedProviders>
                    </Suspense>
                </NextIntlClientProvider>
                <GoogleAnalytics />
            </body>
        </html>
    );
}
export default RootLayout;
