import {
    Listbox,
    ListboxButton,
    ListboxOption,
    ListboxOptions,
} from "@headlessui/react";
import { Dispatch, SetStateAction, useState } from "react";
import { HiChevronUpDown } from "react-icons/hi2";
import { BsCheck2 } from "react-icons/bs";

type TListBoxItem = {
    id: number;
    name: string;
    value: string;
};
type TListBoxProps = {
    list: Array<TListBoxItem>;
    value: TListBoxItem;
    onChange: Dispatch<SetStateAction<TListBoxItem>>;
};
export default function ListBox({
    list,
    value: selected,
    onChange: setSelected,
}: Readonly<TListBoxProps>) {
    return (
        <>
            <Listbox value={selected} onChange={setSelected}>
                <ListboxButton className="bg-white relative w-full rounded-xl py-1.5 pr-5 text-left text-neutral shadow-sm border border-base-100 ring-2 ring-inset ring-transparent focus:outline-none focus:ring-2 focus:ring-[#ddd] sm:text-sm sm:leading-6 ">
                    <span className="flex items-center">
                        <span className="ml-3 max-w-[85%] block truncate">
                            {selected.name}
                        </span>
                    </span>
                    <span className="pointer-events-none absolute inset-y-0 right-0 ml-3 flex items-center pr-2">
                        <HiChevronUpDown className="h-5 w-5 text-gray-400" />
                    </span>
                </ListboxButton>
                <ListboxOptions
                    transition
                    portal={false}
                    className="data-[closed]:scale-95 data-[closed]:opacity-0 px-1 box-shadow-tf bg-white opacity-100 pointer-events-auto transition-all absolute z-40 mt-1 max-h-56 w-full overflow-auto rounded-xl py-1 text-base shadow-lg ring-1 ring-black ring-opacity-5 focus:outline-none sm:text-sm"
                    as="ul"
                >
                    {list.map((item) => (
                        <ListboxOption key={item.id} value={item} as="li">
                            <div className="text-neutral rounded-[10px] bg-base bg-opacity-0 hover:bg-opacity-50 transition-all relative select-none py-2 pr-4 cursor-pointer">
                                <div className="flex items-center">
                                    <span className="font-normal ml-3 max-w-[85%] block truncate overflow-hidden">
                                        {item.name}
                                    </span>
                                    {selected.id === item.id ? (
                                        <span className="text-neutral absolute inset-y-0 right-0 flex items-center pr-1">
                                            <BsCheck2 className="h-4 w-4 text-gray-400" />
                                        </span>
                                    ) : (
                                        ""
                                    )}
                                </div>
                            </div>
                        </ListboxOption>
                    ))}
                </ListboxOptions>
            </Listbox>
        </>
    );
}
