// components/PaymentDialog.tsx
import * as Dialog from "@radix-ui/react-dialog";
import { IoClose } from "react-icons/io5";
import { useTranslations } from "next-intl";
import { FaAlipay, FaPaypal } from "react-icons/fa";

interface PaymentDialogProps {
    open: boolean;
    setOpen: (open: boolean) => void;
    onHandlePay: (platform: "paypal" | "alipay") => void;
}

export default function PaymentDialog({
    open,
    setOpen,
    onHandlePay,
}: PaymentDialogProps) {
    const t = useTranslations("pricing"); // 使用翻译
    return (
        <Dialog.Root open={open} onOpenChange={setOpen}>
            <Dialog.Portal>
                <Dialog.Overlay className="bg-black bg-opacity-50 fixed inset-0" />
                <Dialog.Content className="fixed top-1/2 left-1/2 w-full max-w-md p-6 bg-white rounded-xl transform -translate-x-1/2 -translate-y-1/2 shadow-lg">
                    <Dialog.Title className="text-lg font-bold">
                        {/* 选择支付方式 */}
                        {t("ChoosePaymentMethod")}
                    </Dialog.Title>
                    <Dialog.Description className="mt-2 text-sm text-gray-600">
                        {/* 请选择您要使用的支付方式 */}
                        {t("SelectPaymentMethod")}
                    </Dialog.Description>
                    <div className="mt-4 space-y-2">
                        <button
                            onClick={() => onHandlePay("paypal")}
                            className="btn w-full btn-secondary  "
                        >
                            <FaPaypal size={24} className="text-white" />
                            PayPal
                        </button>
                        <button
                            onClick={() => onHandlePay("alipay")}
                            className="btn w-full btn-outline border-2 border-blue-500 text-blue-500 hover:bg-blue-500/20 hover:border-blue-500 hover:text-blue-500"
                        >
                            {/* 支付宝支付 */}
                            <FaAlipay size={24} /> Alipay
                        </button>
                    </div>
                    <Dialog.Close asChild>
                        <button className="absolute top-2 right-2 text-gray-500 hover:text-gray-700">
                            <IoClose size={24} />
                        </button>
                    </Dialog.Close>
                </Dialog.Content>
            </Dialog.Portal>
        </Dialog.Root>
    );
}
