"use client";
import useFetch from "@/hooks/useFetch";
// context/UserContext.tsx
import React, { createContext, useContext, useState, ReactNode } from "react";

interface User {
    username: string;
    email: string;
    phone: string;
    isMember: boolean;
    points: number;
    referralCode: string;
    commissionRate: number;
}

// 定义上下文的类型
interface UserContextType {
    user: User | null;
    setUser: (user: User | null) => void;
}

// 创建上下文，初始值为 null
const UserContext = createContext<UserContextType | null>(null);

// 创建 Provider 组件
export const UserProvider: React.FC<{ children: ReactNode }> = ({
    children,
}) => {
    const [user, setUser] = useState<User | null>(null);
    const {
        fetchData: GetUserinfo,
        loading: userinfoLoading,
        data: userinfoData,
    } = useFetch({
        url: "/api/profile/",
        method: "GET",
    });
    // GetUserinfo().then((res) => {
    //     console.log("userinfo", res);
    // });
    return (
        <UserContext.Provider value={{ user, setUser }}>
            {children}
        </UserContext.Provider>
    );
};

// 自定义钩子，方便在组件中使用上下文
export const useUser = (): UserContextType => {
    const context = useContext(UserContext);
    if (!context) {
        throw new Error("useUser must be used within a UserProvider");
    }
    return context;
};
