import { getRequestConfig } from 'next-intl/server';
import { headers } from "next/headers";

export default getRequestConfig(async () => {
    const headersList = headers();
    const acceptLanguage = headersList.get("accept-language");

    // 提取首选语言
    let locale = 'en'; // 默认语言
    if (acceptLanguage) {
        // 根据首选语言选择合适的 locale
        const preferredLanguages = acceptLanguage.split(',')
            .map(lang => lang.split(';')[0].trim().slice(0, 2)); // 提取语言的前两个字符，如 'zh-CN' -> 'zh'
        const supportedLocales = ['en', 'zh']; // 支持的语言列表

        // 检查首选语言是否在支持的语言列表中
        for (const lang of preferredLanguages) {
            if (supportedLocales.includes(lang)) {
                locale = lang;
                break;
            }
        }
    }

    return {
        locale,
        messages: (await import(`../../public/locales/${locale}.json`)).default
    };
});
