import { NextResponse } from 'next/server';
import type { NextRequest } from 'next/server';
import routes from '@/models/routes';
import { match } from '@formatjs/intl-localematcher';
import Negotiator from 'negotiator';

// 支持的语言
const locales = ['en-US', 'zh'];
const defaultLocale = 'en-US';

export function middleware(request: NextRequest) {
    const { pathname } = request.nextUrl; // 获取请求的路径

    // 获取请求中的 cookie
    const sessionid = request.cookies.get('sessionid'); // 假设你的 session id 是 'sessionid'
    const url = new URL(request.url);

    // // 获取用户的语言设置
    // const negotiatorHeaders = { 'accept-language': request.headers.get('accept-language') || '' };
    // const languages = new Negotiator({ headers: negotiatorHeaders }).languages();
    // const selectedLocale = match(languages, locales, defaultLocale);
    // console.log('languages', languages, selectedLocale)
    // 如果用户已登录，且访问的是登录页面，则重定向到创建页面
    // if (sessionid && pathname === '/login') {
    //     return NextResponse.redirect(new URL('/create', request.url));
    // }

    // 查找当前路径是否需要认证
    const route = routes.find(route => pathname === route.path);

    // 如果路由需要认证，且没有 sessionid，则重定向到登录页面
    if (route && route.requiresAuth && !sessionid) {
        return NextResponse.redirect(new URL('/login', request.url));
    }
    const openid = url.searchParams.get('openid');

    // 如果 URL 中存在 openid 参数
    if (openid) {
        // 创建一个新的响应对象，并设置 cookie
        const response = NextResponse.next();
        response.cookies.set('openid', openid, {
            path: '/',
            httpOnly: true,
            maxAge: 60 * 60 * 24 // 设置cookie有效期为1天
        });
        return response;
    }
    // 在返回响应时，将用户的语言环境设置到响应头中
    const response = NextResponse.next();
    // response.headers.set('Content-Language', selectedLocale);

    // 继续处理请求
    return response;
}
