import InputBox from "@/components/InputBox";
import { useToast } from "@/contexts/ToastContext";
import useFetch from "@/hooks/useFetch";
import classNames from "classnames";
import { use, useEffect, useState } from "react";
import useLoadingStore from "@/store/loadingStore";
import { useRouter } from "next/navigation";
import { Field, Label, Radio, RadioGroup } from "@headlessui/react";
import { useTranslations } from "next-intl";
import Image from "next/image";

const models = ["gen2", "gen3"];
const ratios = [
    {
        label: "16:9",
        id: 1,
        value: {
            width: 1920,
            height: 1080,
        },
        model: ["gen2", "gen3"],
    },
    {
        label: "9:16",
        id: 2,
        value: {
            width: 1080,
            height: 1920,
        },
        model: ["gen2"],

        tooltip: "仅在Gen2模型下支持9:16",
    },
    {
        label: "1:1",
        id: 3,
        value: {
            width: 1080,
            height: 1080,
        },
        model: ["gen2"],
        tooltip: "仅在Gen2模型下支持1:1",
    },
];
const times = [
    {
        label: "4s",
        id: 1,
        value: 4,
        model: "gen2",
        tooltip: "仅在Gen2模型下支持4s",
    },
    {
        label: "5s",
        id: 2,
        value: 5,
        model: "gen3",
        tooltip: "仅在Gen3模型下支持5s",
    },
    {
        label: "10s",
        id: 3,
        value: 10,
        model: "gen3",
        tooltip: "仅在Gen3模型下支持10s",
    },
];

const styles = [
    {
        name: "",
        image: "/images/default.jpg",
        label: "默认",
    },
    {
        name: "abandoned",
        image: "/images/abandoned.jpg",
        label: "废弃",
    },
    {
        name: "abstract_sculpture",
        image: "/images/abstract_sculpture.jpg",
        label: "抽象",
    },
    {
        name: "advertising",
        image: "/images/advertising.jpg",
        label: "广告",
    },
    {
        name: "anime",
        image: "/images/anime.jpg",
        label: "动漫",
    },
    {
        name: "cine_lens",
        image: "/images/cine_lens.jpg",
        label: "电影镜头",
    },
    {
        name: "cinematic",
        image: "/images/cinematic.jpg",
        label: "电影",
    },
    {
        name: "concept_art",
        image: "/images/concept_art.jpg",
        label: "艺术",
    },
    {
        name: "forestpunk",
        image: "/images/forestpunk.jpg",
        label: "赛博朋克",
    },
    {
        name: "frost",
        image: "/images/frost.jpg",
        label: "雪",
    },
    {
        name: "graphite",
        image: "/images/graphite.jpg",
        label: "石墨",
    },
    {
        name: "macro_photography",
        image: "/images/macro_photography.jpg",
        label: "宏观",
    },
    {
        name: "pixel_art",
        image: "/images/pixel_art.jpg",
        label: "像素艺术",
    },
    {
        name: "retro_photography",
        image: "/images/retro_photography.jpg",
        label: "复古",
    },
    {
        name: "sci_fi_art",
        image: "/images/sci_fi_art.jpg",
        label: "科幻",
    },
    {
        name: "thriller",
        image: "/images/thriller.jpg",
        label: "惊悚",
    },
    {
        name: "35mm",
        image: "/images/35mm.jpg",
        label: "35mm",
    },
    // {
    //     name: "vector",
    //     image: "https://www.typeframes.com/_next/image?url=%2Fpresets%2FLEONARDO.webp&w=256&q=75",
    //     label: "矢量",
    // },
    // {
    //     name: "watercolor",
    //     image: "https://www.typeframes.com/_next/image?url=%2Fpresets%2FLEONARDO.webp&w=256&q=75",
    //     label: "水彩",
    // },
];

export default function TextVideo() {
    const router = useRouter();
    const t = useTranslations("tiktok");
    const s = useTranslations("style");
    const { addToast, addToastSuccess, addToastError } = useToast();
    const [rate, setRate] = useState(5);
    let [model, setModel] = useState(models[0]);
    const [selectedStyle, setSelectedStyle] = useState(""); // 默认风格为空

    const showLoading = useLoadingStore((state) => state.showLoading);
    const hideLoading = useLoadingStore((state) => state.hideLoading);

    const {
        fetchData: createFetch,
        loading: createLoading,
        data: createResult,
    } = useFetch({
        url: "/api/text-to-video/",
        method: "POST",
    });
    const create = () => {
        const requestData = {
            text_prompt: text,
            model: model,
            time: time.value,
            style: selectedStyle,
            motion: rate,
        };
        if (text === "") {
            addToastError(t("enterVideoText"));
            return;
        }
        if (model === "gen2") {
            requestData["width"] = ratio.value.width;
            requestData["height"] = ratio.value.height;
        }
        console.log("requestData", requestData);
        showLoading("creating...");
        createFetch(requestData)
            .then((res) => {
                addToastSuccess(t("createSuccess"));
                router.push("/projects");
            })
            .finally(() => {
                hideLoading();
            });
    };

    const [ratio, setRatio] = useState(ratios[0]);
    const [time, setTime] = useState(times[0]);
    const [text, setText] = useState("");

    const modelChange = (e) => {
        setModel(e);
        if (!ratio.model.includes(e)) {
            for (let i of ratios) {
                if (i.model.includes(e)) {
                    setRatio(i);
                    break;
                }
            }
        }
        if (!time.model !== e) {
            for (let i of times) {
                if (i.model === e) {
                    setTime(i);
                    break;
                }
            }
        }
    };

    return (
        <>
            <p className="text-info text-sm">{t("useTool")}</p>
            <InputBox serial={1} title={t("creativeDescription")}>
                <textarea
                    onChange={(e) => setText(e.target.value)}
                    className="min-h-36 textarea text-neutral placeholder:text-gray-300 font-normal outline-base-200 focus:outline-offset-[1px] outline outline-[1.5px] focus:outline-[1.5px] focus:base-200 rounded-lg bg-transparent overflow-hidden text-base resize-none p-4"
                    placeholder={t("text-to-video")}
                ></textarea>
                <small className="whitespace-pre-line text-info">
                    {t("videoTextTip")}
                </small>
            </InputBox>
            <InputBox serial={2} title={t("videoStyle")}>
                <div className="w-full p-2">
                    <div className="flex space-x-4 overflow-x-scroll snap-x snap-mandatory scrollbar-custom">
                        {styles.map((style, index) => (
                            <div
                                key={index}
                                className="snap-start flex-shrink-0 cursor-pointer"
                                onClick={() => setSelectedStyle(style.name)} // 选择风格
                            >
                                <div className="text-sm mb-1 ml-2 text-info">
                                    {s(style.name)}
                                </div>
                                <Image
                                    src={style.image}
                                    alt={style.name}
                                    width={128}
                                    height={160}
                                    className={classNames(
                                        "w-32 h-32 mb-2 border-4 object-cover rounded-lg hover:shadow-md",
                                        {
                                            "border-secondary":
                                                selectedStyle === style.name,
                                        }
                                    )}
                                />
                            </div>
                        ))}
                    </div>
                </div>
            </InputBox>
            <InputBox serial={3} title={t("pickParameters")}>
                <div className="flex flex-col gap-8">
                    <div className="flex gap-2 flex-col md:flex-row md:items-center">
                        <div className="min-w-[160px] flex flex-col ml-2">
                            <div className="text-gray-700 text-md">
                                {t("selectionModel")}
                            </div>
                            {/* <div className="text-info text-xs">
                                {t("dynamicOrVideo")}
                            </div> */}
                        </div>
                        <div className="">
                            <RadioGroup
                                value={model}
                                onChange={modelChange}
                                aria-label="Server size"
                                className="flex items-center gap-4"
                            >
                                {models.map((model) => (
                                    <Field key={model}>
                                        <Radio
                                            value={model}
                                            className="group flex items-center gap-2 bg-base-100 rounded-xl py-2 px-4 cursor-pointer border-2 border-base-200/50 data-[checked]:border-secondary data-[checked]:bg-secondary/5"
                                        >
                                            <div className="flex size-5 items-center justify-center rounded-full border bg-white group-data-[checked]:bg-secondary">
                                                <span className="invisible size-2 rounded-full bg-white group-data-[checked]:visible" />
                                            </div>
                                            <Label className="cursor-pointer">
                                                {model}
                                            </Label>
                                        </Radio>
                                    </Field>
                                ))}
                            </RadioGroup>
                        </div>
                    </div>
                    <div className="flex gap-2 flex-col md:flex-row md:items-center">
                        <div className="min-w-[160px] flex flex-col ml-2">
                            <div className="text-gray-700 text-md">
                                {t("chooseScreenRatio")}
                            </div>
                            <div className="text-info text-xs">
                                {t("adaptScreenRatio")}
                            </div>
                        </div>
                        <div className="">
                            <RadioGroup
                                value={ratio}
                                onChange={setRatio}
                                aria-label="Video aspect ratio"
                            >
                                <div className="flex space-x-10">
                                    {ratios.map((ratio) => (
                                        <Field
                                            key={ratio.id}
                                            className="group relative flex flex-col items-center justify-end gap-2"
                                            disabled={
                                                !ratio.model.includes(model)
                                            }
                                        >
                                            <Radio
                                                value={ratio}
                                                className="group cursor-pointer flex flex-1 items-center"
                                            >
                                                <div
                                                    className={`rounded-md bg-white/0 border-4 border-base-300 ${
                                                        ratio.label === "16:9"
                                                            ? "w-16 h-9"
                                                            : ratio.label ===
                                                              "9:16"
                                                            ? "w-9 h-16"
                                                            : "w-12 h-12"
                                                    } group-data-[checked]:border-secondary`}
                                                ></div>
                                            </Radio>
                                            <Label className="text-sm cursor-pointer">
                                                {ratio.label}
                                            </Label>
                                            {!ratio.model.includes(model) && (
                                                <div className="w-max absolute left-1/2 transform -translate-x-1/2 bottom-full mb-2 bg-gray-700 text-white text-xs rounded py-1 px-2 opacity-0 group-hover:opacity-100 transition-opacity">
                                                    {ratio.tooltip}
                                                    <div className="absolute left-1/2 transform -translate-x-1/2 -translate-y-1/2 top-full w-2 h-2 bg-gray-700 rotate-45"></div>
                                                </div>
                                            )}
                                        </Field>
                                    ))}
                                </div>
                            </RadioGroup>
                        </div>
                    </div>
                    <div className="flex gap-2 flex-col md:flex-row md:items-center">
                        <div className="min-w-[160px] flex flex-col ml-2 ">
                            <div className="text-gray-700 text-md">
                                {t("creativeImagination")}
                            </div>
                            <div className="text-info text-xs">
                                {t("creativityProgressBar")}
                            </div>
                        </div>
                        <div className="w-full max-w-[400px]">
                            <div className="w-full">
                                <input
                                    type="range"
                                    min={0}
                                    max={10}
                                    value={rate}
                                    className="range range-secondary range-sm"
                                    step={1}
                                    onChange={(e) =>
                                        setRate(Number(e.target.value))
                                    }
                                />
                            </div>
                            <div className="flex w-full justify-between px-2 text-xs">
                                <span>|</span>
                                <span>|</span>
                                <span>|</span>
                                <span>|</span>
                                <span>|</span>
                                <span>|</span>
                                <span>|</span>
                                <span>|</span>
                                <span>|</span>
                                <span>|</span>
                                <span>|</span>
                            </div>
                        </div>
                    </div>
                    <div className="flex gap-2 flex-col md:flex-row md:items-center">
                        <div className="min-w-[160px] flex flex-col ml-2">
                            <div className="text-gray-700 text-md">
                                {t("selectVideoDuration")}
                            </div>
                            {/* <div className="text-info text-xs">
                                选择视频时长
                            </div> */}
                        </div>
                        <div className="">
                            <RadioGroup
                                value={time}
                                onChange={setTime}
                                aria-label="Video aspect ratio"
                            >
                                <div className="flex space-x-10">
                                    {times.map((time) => (
                                        <Field
                                            key={time.id}
                                            className="relative flex items-center gap-2 group"
                                            disabled={time.model != model}
                                        >
                                            <Radio
                                                value={time}
                                                className="group flex size-5 items-center justify-center rounded-full border cursor-pointer bg-white data-[checked]:bg-secondary data-[disabled]:bg-base-200"
                                            >
                                                <span className="invisible size-2 rounded-full bg-white group-data-[checked]:visible" />
                                            </Radio>
                                            <Label className="cursor-pointer">
                                                {time.label}
                                            </Label>
                                            {time.model !== model && (
                                                <div className="w-max absolute left-1/2 transform -translate-x-1/2 bottom-full mb-2 bg-gray-700 text-white text-xs rounded py-1 px-2 opacity-0 group-hover:opacity-100 transition-opacity">
                                                    {time.tooltip}
                                                    <div className="absolute left-1/2 transform -translate-x-1/2 -translate-y-1/2 top-full w-2 h-2 bg-gray-700 rotate-45"></div>
                                                </div>
                                            )}
                                        </Field>
                                    ))}
                                </div>
                            </RadioGroup>
                        </div>
                    </div>
                </div>
            </InputBox>
            <div className="relative flex items-end">
                <button
                    onClick={create}
                    className="inline-flex gap-1.5 items-center justify-center whitespace-nowrap z-0 text-sm font-medium ring-offset-background transition-all focus-visible:outline-none focus-visible:ring-2 focus-visible:ring-ring focus-visible:ring-offset-2 disabled:pointer-events-none disabled:opacity-50 bg-black border border-black relative w-auto text-white px-4 py-2 rounded-md"
                >
                    {t("generateVideo")}
                </button>
                <div className="flex flex-col">
                    <span className="opacity-60 ml-4 gap-1 text-sm items-center">
                        {t("originalPrice")}{" "}
                        <b className="line-through">20{t("credits")}</b>
                    </span>
                    <span className="ml-4 gap-1 text-sm items-center text-info">
                        {t("currentPrice")} <b>10 {t("credits")}</b>
                    </span>
                </div>
            </div>
        </>
    );
}
