import InputBox from "@/components/InputBox";
import ListBox from "@/components/ListBox";
import { useToast } from "@/contexts/ToastContext";
import useFetch from "@/hooks/useFetch";
import classNames from "classnames";
import { useState } from "react";
import VideoSelect, { VideoData } from "../components/video";
import useLoadingStore from "@/store/loadingStore";
import { useRouter } from "next/navigation";
import styles from "./index.module.css";
import { useTranslations } from "next-intl";
import { Switch } from "@headlessui/react";
import {
    PiAlignTopSimple,
    PiAlignCenterVerticalSimple,
    PiAlignBottomSimple,
} from "react-icons/pi";

export default function Tiktok() {
    const t = useTranslations("tiktok");

    const router = useRouter();

    const { addToast, addToastSuccess, addToastError } = useToast();
    const [rate, setRate] = useState(0.1);
    const [enabledCaptions, setEnabledCaptions] = useState(false);
    const ratioList = [
        {
            name: "16 / 9",
            id: 1,
            value: "16 / 9",
        },
        {
            name: "1 / 1",
            id: 2,
            value: "1 / 1",
        },
        {
            name: "9 / 16",
            id: 3,
            value: "9 / 16",
        },
    ];
    const showLoading = useLoadingStore((state) => state.showLoading);
    const hideLoading = useLoadingStore((state) => state.hideLoading);

    const {
        fetchData: createFetch,
        loading: createLoading,
        data: createResult,
    } = useFetch({
        url: "/api/create-tiktok-video/",
        method: "POST",
    });
    const create = () => {
        const requestData = {
            text: text,
            voice: videoData.videoSelect,
            style: videoData.style,
            ratio: ratio.value,
            rate: rate,
            mediaType: mediaType.value,
            slug: "create-tiktok-video",
            disableCaptions: !enabledCaptions,
        };
        if (enabledCaptions) {
            requestData["captionPreset"] = captionPreset;
            requestData["captionPosition"] = captionPosition;
        }
        console.log(requestData);
        if (text === "") {
            addToastError(t("enterVideoText"));
            return;
        }
        console.log("requestData", requestData);
        showLoading("creating...");
        createFetch(requestData)
            .then((res) => {
                console.log("create result：", res);
                if (res.success === 1) {
                    addToastSuccess(t("createSuccess"));
                    router.push("/projects");
                } else {
                    addToastError(t("createFailed"));
                }
            })
            .finally(() => {
                hideLoading();
            });
    };

    const [ratio, setRatio] = useState(ratioList[0]);

    const [captionPreset, setCaptionPreset] = useState("Wrap 1");

    const [captionPosition, setCaptionPosition] = useState("bottom");
    const mediaTypeList = [
        { id: 1, name: t("stockVideo"), value: "stockVideo" },
        { id: 2, name: t("movingImage"), value: "movingImage" },
    ];

    const [mediaType, setMediaType] = useState(mediaTypeList[1]);

    const [videoData, setVideoData] = useState<VideoData>({
        language: "", // 国家语种
        videoSelect: "", // 讲话人
        style: "", // 讲话风格
    });
    const handleVideoDataChange = (newData: VideoData) => {
        setVideoData(newData);
    };

    const [text, setText] = useState("");

    return (
        <>
            <p className="text-info text-sm">{t("useTool")}</p>
            <InputBox serial={1} title={t("yourVideoText")}>
                <textarea
                    onChange={(e) => setText(e.target.value)}
                    className="min-h-36 textarea text-neutral placeholder:text-gray-300 font-normal outline-base-200 focus:outline-offset-[1px] outline outline-[1.5px] focus:outline-[1.5px] focus:base-200 rounded-lg bg-transparent overflow-hidden text-base resize-none p-4"
                    placeholder={t("create-tiktok-video")}
                ></textarea>
                <small className="whitespace-pre-line text-info">
                    {t("videoTextTip")}
                </small>
            </InputBox>
            <InputBox serial={2} title={t("selectVoice")}>
                {/* <small className="text-info text-xs">
                    {t("voicePunctuationTip")}
                </small> */}
                <VideoSelect onChange={handleVideoDataChange} />
            </InputBox>
            <InputBox serial={3} title={t("pickParameters")}>
                <div className="flex gap-2 flex-col md:flex-row md:items-center">
                    <div className="min-w-[200px]">
                        <div className="relative group">
                            <ListBox
                                list={mediaTypeList}
                                value={mediaType}
                                onChange={setMediaType}
                            />
                        </div>
                    </div>
                    <div className="flex flex-col ml-2">
                        <div className="text-gray-700 text-md">
                            {t("selectFootageType")}
                        </div>
                        <div className="text-info text-xs">
                            {t("dynamicOrVideo")}
                        </div>
                    </div>
                </div>
                <div className="flex gap-2 flex-col md:flex-row md:items-center">
                    <div className="min-w-[200px]">
                        <div className="relative group">
                            <ListBox
                                list={ratioList}
                                value={ratio}
                                onChange={setRatio}
                            />
                        </div>
                    </div>
                    <div className="flex flex-col ml-2">
                        <div className="text-gray-700 text-md">
                            {t("chooseScreenRatio")}
                        </div>
                        <div className="text-info text-xs">
                            {t("adaptScreenRatio")}
                        </div>
                    </div>
                </div>
                <div className="flex gap-2 flex-col md:flex-row md:items-center">
                    <div className="w-full max-w-[400px]">
                        <div className="w-full">
                            <input
                                type="range"
                                min={0.1}
                                max={1}
                                value={rate}
                                className="range range-secondary range-sm"
                                step={0.1}
                                onChange={(e) =>
                                    setRate(Number(e.target.value))
                                }
                            />
                        </div>
                        <div className="flex w-full justify-between px-2 text-xs">
                            <span>|</span>
                            <span>|</span>
                            <span>|</span>
                            <span>|</span>
                            <span>|</span>
                            <span>|</span>
                            <span>|</span>
                            <span>|</span>
                            <span>|</span>
                            <span>|</span>
                        </div>
                    </div>
                    <div className="flex flex-col ml-2">
                        <div className="text-gray-700 text-md">
                            {t("chooseSpeakerSpeek")}
                        </div>
                        <div className="text-info text-xs">
                            {t("chooseSpeakerSpeekIntro")}
                        </div>
                    </div>
                </div>
            </InputBox>
            <InputBox serial={4} title={t("chooseGenerationPreset")}>
                <div className="flex flex-col w-full h-full relative">
                    <div className="overflow-auto px-12 pb-6 pt-6 h-full no-scrollbar">
                        <div className="flex flex-col w-full">
                            <div className="flex items-center mb-4">
                                <Switch
                                    checked={enabledCaptions}
                                    onChange={setEnabledCaptions}
                                    className="mr-2 group inline-flex h-6 w-11 items-center rounded-full bg-base-200 transition data-[checked]:bg-secondary"
                                >
                                    <span className="size-4 translate-x-1 rounded-full bg-white transition group-data-[checked]:translate-x-6" />
                                </Switch>
                                <div className="text-gray-500">
                                    {t("enabledCaptions")}
                                </div>
                            </div>
                            {enabledCaptions && (
                                <>
                                    <div className="w-full mb-3 flex items-center justify-between">
                                        <div className="text-sm font-base text-gray-500 inline-flex gap-2 items-center">
                                            {t("selectPreset")}
                                        </div>
                                    </div>

                                    <div className="grid grid-cols-3 gap-2 w-full">
                                        <div
                                            className={classNames(
                                                "rounded-md px-2 py-4 flex items-center justify-center w-full relative gap-1 cursor-pointer outline-offset-2 outline-2 border transition-all bg-white hover:bg-base-100/50 border-base-100",
                                                {
                                                    "border-secondary":
                                                        captionPreset ===
                                                        "Basic",
                                                    "hover:border-base-200":
                                                        captionPreset !==
                                                        "Basic",
                                                }
                                            )}
                                            onClick={() =>
                                                setCaptionPreset("Basic")
                                            }
                                        >
                                            <span
                                                className="heavy-shadow-text-effect"
                                                style={
                                                    {
                                                        position: "relative",
                                                        "--text-content":
                                                            "Basic",
                                                        "--text-color":
                                                            "#FFFFFF",
                                                        color: "rgb(255, 255, 255)",
                                                        fontFamily:
                                                            "Montserrat, sans-serif",
                                                        fontWeight: "bold",
                                                        textDecoration: "none",
                                                        fontStyle: "normal",
                                                        textTransform:
                                                            "uppercase",
                                                        textShadow: `
                                                    .1em .1em .1em #000, 
                                                    .1em -.1em .1em #000, 
                                                    -.1em .1em .1em #000, 
                                                    -.1em -.1em .1em #000, 
                                                    .1em .1em .2em #000, 
                                                    .1em -.1em .2em #000, 
                                                    -.1em .1em .2em #000, 
                                                    -.1em -.1em .2em #000, 
                                                    0 0 .1em #000, 
                                                    0 0 .2em #000, 
                                                    0 0 .3em #000, 
                                                    0 0 .4em #000, 
                                                    0 0 .5em #000, 
                                                    0 0 .6em #000
                                                  `,
                                                    } as React.CSSProperties
                                                }
                                            >
                                                Basic
                                            </span>
                                        </div>

                                        <div
                                            className={classNames(
                                                "rounded-md px-2 py-4 flex items-center justify-center w-full relative gap-1 cursor-pointer outline-offset-2 outline-2 border transition-all bg-white hover:bg-base-100/50 border-base-100",
                                                {
                                                    "border-secondary":
                                                        captionPreset ===
                                                        "REVID",
                                                    "hover:border-base-200":
                                                        captionPreset !==
                                                        "REVID",
                                                }
                                            )}
                                            onClick={() =>
                                                setCaptionPreset("REVID")
                                            }
                                        >
                                            <span
                                                className={
                                                    styles["stroke-text"]
                                                }
                                                style={{
                                                    fontFamily:
                                                        "Poppins, sans-serif",
                                                }}
                                                data-text="REVID"
                                            >
                                                REVID
                                            </span>
                                        </div>

                                        <div
                                            className={classNames(
                                                "rounded-md px-2 py-4 flex items-center justify-center w-full relative gap-1 cursor-pointer outline-offset-2 outline-2 border transition-all bg-white hover:bg-base-100/50 border-base-100",
                                                {
                                                    "border-secondary":
                                                        captionPreset ===
                                                        "Hormozi",
                                                    "hover:border-base-200":
                                                        captionPreset !==
                                                        "Hormozi",
                                                }
                                            )}
                                            onClick={() =>
                                                setCaptionPreset("Hormozi")
                                            }
                                        >
                                            <span
                                                className={
                                                    styles["glow-text-effect"]
                                                }
                                                style={
                                                    {
                                                        position: "relative",
                                                        "--text-content":
                                                            "Hormozi",
                                                        "--text-effect-color":
                                                            "#FFED38",
                                                        "--text-color":
                                                            "#FFED38",
                                                        color: "rgb(255, 237, 56)",
                                                        fontFamily:
                                                            "Anton, sans-serif",
                                                        fontWeight: "bold",
                                                        textDecoration: "none",
                                                        fontStyle: "normal",
                                                        textTransform:
                                                            "uppercase",
                                                    } as React.CSSProperties
                                                }
                                            >
                                                Hormozi
                                            </span>
                                        </div>

                                        <div
                                            className={classNames(
                                                "rounded-md px-2 py-4 flex items-center justify-center w-full relative gap-1 cursor-pointer outline-offset-2 outline-2 border transition-all bg-white hover:bg-base-100/50 border-base-100",
                                                {
                                                    "border-secondary":
                                                        captionPreset === "Ali",
                                                    "hover:border-base-200":
                                                        captionPreset !== "Ali",
                                                }
                                            )}
                                            onClick={() =>
                                                setCaptionPreset("Ali")
                                            }
                                        >
                                            <span
                                                className="wrap-text-effect"
                                                style={
                                                    {
                                                        position: "relative",
                                                        "--text-content": "Ali",
                                                        "--text-effect-color":
                                                            "#FFFFFF",
                                                        "--text-color":
                                                            "#1C1E1D",
                                                        color: "rgb(28, 30, 29)",
                                                        fontFamily:
                                                            "Poppins, sans-serif",
                                                        fontWeight: "bold",
                                                        textDecoration: "none",
                                                        fontStyle: "normal",
                                                        textTransform: "none",
                                                    } as React.CSSProperties
                                                }
                                            >
                                                Ali
                                            </span>
                                        </div>

                                        <div
                                            className={classNames(
                                                "rounded-md px-2 py-4 flex items-center justify-center w-full relative gap-1 cursor-pointer outline-offset-2 outline-2 border transition-all bg-white hover:bg-base-100/50 border-base-100",
                                                {
                                                    "border-secondary":
                                                        captionPreset ===
                                                        "Wrap 1",
                                                    "hover:border-base-200":
                                                        captionPreset !==
                                                        "Wrap 1",
                                                }
                                            )}
                                            onClick={() =>
                                                setCaptionPreset("Wrap 1")
                                            }
                                        >
                                            <span
                                                className={
                                                    styles["stroke-text"]
                                                }
                                                style={
                                                    {
                                                        position: "relative",
                                                        "--text-content":
                                                            "Wrap 1",
                                                        "--text-color":
                                                            "#f6f6db",
                                                        color: "rgb(246, 246, 219)",
                                                        fontFamily:
                                                            "Lexend, sans-serif",
                                                        fontWeight: "bold",
                                                        textDecoration: "none",
                                                        fontStyle: "normal",
                                                        textTransform: "none",
                                                    } as React.CSSProperties
                                                }
                                                data-text="Wrap 1"
                                            >
                                                <span
                                                    style={{
                                                        background:
                                                            "rgb(248, 66, 60)",
                                                        position: "absolute",
                                                        inset: "-0.2em -0.4em",
                                                        borderRadius: "0.4em",
                                                        zIndex: -2,
                                                    }}
                                                ></span>
                                                Wrap 1
                                            </span>
                                        </div>

                                        <div
                                            className={classNames(
                                                "rounded-md px-2 py-4 flex items-center justify-center w-full relative gap-1 cursor-pointer outline-offset-2 outline-2 border transition-all bg-white hover:bg-base-100/50 border-base-100",
                                                {
                                                    "border-secondary":
                                                        captionPreset ===
                                                        "Wrap 2",
                                                    "hover:border-base-200":
                                                        captionPreset !==
                                                        "Wrap 2",
                                                }
                                            )}
                                            onClick={() =>
                                                setCaptionPreset("Wrap 2")
                                            }
                                        >
                                            <span
                                                className={
                                                    styles["stroke-text"]
                                                }
                                                style={
                                                    {
                                                        position: "relative",
                                                        "--text-content":
                                                            "Wrap 2",
                                                        "--text-color":
                                                            "#ffffff",
                                                        color: "rgb(255, 255, 255)",
                                                        fontFamily:
                                                            "Poppins, sans-serif",
                                                        fontWeight: "bold",
                                                        textDecoration: "none",
                                                        fontStyle: "normal",
                                                        textTransform:
                                                            "uppercase",
                                                    } as React.CSSProperties
                                                }
                                                data-text="Wrap 2"
                                            >
                                                <span
                                                    style={{
                                                        background:
                                                            "rgb(121, 212, 246)",
                                                        position: "absolute",
                                                        inset: "-0.05em -0.5em",
                                                        borderRadius: "0.2em",
                                                        zIndex: -2,
                                                    }}
                                                ></span>
                                                Wrap 2
                                            </span>
                                        </div>

                                        <div
                                            className={classNames(
                                                "rounded-md px-2 py-4 flex items-center justify-center w-full relative gap-1 cursor-pointer outline-offset-2 outline-2 border transition-all bg-white hover:bg-base-100/50 border-base-100",
                                                {
                                                    "border-secondary":
                                                        captionPreset ===
                                                        "Faceless",
                                                    "hover:border-base-200":
                                                        captionPreset !==
                                                        "Faceless",
                                                }
                                            )}
                                            onClick={() =>
                                                setCaptionPreset("Faceless")
                                            }
                                        >
                                            <span
                                                className={
                                                    styles["bevel-text-effect"]
                                                }
                                                style={
                                                    {
                                                        position: "relative",
                                                        "--text-content":
                                                            "Faceless",
                                                        "--text-color":
                                                            "#D8D7D7",
                                                        color: "rgb(216, 215, 215)",
                                                        fontFamily:
                                                            "Lexend, sans-serif",
                                                        fontWeight: "bold",
                                                        textDecoration: "none",
                                                        fontStyle: "normal",
                                                        textTransform:
                                                            "uppercase",
                                                    } as React.CSSProperties
                                                }
                                            >
                                                Faceless
                                            </span>
                                        </div>
                                    </div>

                                    <div className="w-full mt-8 mb-3 flex items-center justify-between">
                                        <div className="text-sm font-base text-gray-500 inline-flex gap-2 items-center">
                                            {t("alignment")}
                                        </div>
                                    </div>

                                    <div className="grid grid-cols-3 gap-2 w-full">
                                        <div
                                            onClick={() =>
                                                setCaptionPosition("top")
                                            }
                                            className={classNames(
                                                "flex items-center justify-center p-2 border border-base-200 text-xs transition-all bg-white hover:bg-white rounded-lg cursor-pointer gap-1 normal-case text-black/50 hover:text-black",
                                                {
                                                    "border-secondary hover:border-secondary":
                                                        captionPosition ===
                                                        "top",
                                                }
                                            )}
                                        >
                                            <PiAlignTopSimple size={20} />
                                            {t("top")}
                                        </div>
                                        <div
                                            onClick={() =>
                                                setCaptionPosition("middle")
                                            }
                                            className={classNames(
                                                "flex items-center justify-center p-2 border border-base-200 text-xs transition-all bg-white hover:bg-white rounded-lg cursor-pointer gap-1 normal-case text-black/50 hover:text-black",
                                                {
                                                    "border-secondary hover:border-secondary":
                                                        captionPosition ===
                                                        "middle",
                                                }
                                            )}
                                        >
                                            <PiAlignCenterVerticalSimple
                                                size={20}
                                            />
                                            {t("middle")}
                                        </div>

                                        <div
                                            onClick={() =>
                                                setCaptionPosition("bottom")
                                            }
                                            className={classNames(
                                                "flex items-center justify-center p-2 border border-base-200 text-xs transition-all bg-white hover:bg-white rounded-lg cursor-pointer gap-1 normal-case text-black/50 hover:text-black",
                                                {
                                                    "border-secondary hover:border-secondary":
                                                        captionPosition ===
                                                        "bottom",
                                                }
                                            )}
                                        >
                                            <PiAlignBottomSimple size={20} />
                                            {t("bottom")}
                                        </div>
                                    </div>
                                </>
                            )}
                        </div>
                    </div>
                </div>
            </InputBox>
            <div className="relative flex items-end">
                <button
                    onClick={create}
                    className="inline-flex gap-1.5 items-center justify-center whitespace-nowrap z-0 text-sm font-medium ring-offset-background transition-all focus-visible:outline-none focus-visible:ring-2 focus-visible:ring-ring focus-visible:ring-offset-2 disabled:pointer-events-none disabled:opacity-50 bg-black border border-black relative w-auto text-white px-4 py-2 rounded-md"
                >
                    {t("generateVideo")}
                </button>
                <div className="flex flex-col">
                    <span className="opacity-60 ml-4 gap-1 text-sm items-center">
                        {t("originalPrice")}{" "}
                        <b className="line-through">30{t("credits")}</b>
                    </span>
                    <span className="ml-4 gap-1 text-sm items-center text-info">
                        {t("currentPrice")}{" "}
                        <b>
                            20 {t("additionalCredits")} 10{" "}
                            {t("additionalCreditsEnd")}
                        </b>
                    </span>
                </div>
            </div>
        </>
    );
}
