import type { Config } from "tailwindcss";
import daisyui from "daisyui"

const config: Config = {
  content: [
    "./src/pages/**/*.{js,ts,jsx,tsx,mdx}",
    "./src/components/**/*.{js,ts,jsx,tsx,mdx}",
    "./src/app/**/*.{js,ts,jsx,tsx,mdx}",
    "./src/ui/**/*.{js,ts,jsx,tsx,mdx}",
    "./src/contexts/**/*.{js,ts,jsx,tsx,mdx}",
  ],
  theme: {
    extend: {
      backgroundImage: {
        "gradient-radial": "radial-gradient(var(--tw-gradient-stops))",
        "gradient-conic":
          "conic-gradient(from 180deg at 50% 50%, var(--tw-gradient-stops))",
      },
      colors: {

      },
      keyframes: {
        'accordion-up': {
          '0%': { height: 'var(--radix-collapsible-content-height)', opacity: "1" },
          '100%': { height: '0', opacity: "0" },
        },
        'accordion-down': {
          '0%': { height: '0', opacity: "0" },
          '100%': { height: 'var(--radix-collapsible-content-height)', opacity: "" },
        },
      },
      animation: {
        'accordion-up': 'accordion-up 0.3s ease-out',
        'accordion-down': 'accordion-down 0.3s ease-out',
      },
    },
  },
  plugins: [
    daisyui,
    require('@tailwindcss/forms'),
  ],
  daisyui: {
    themes: [
      {
        typeframes: {
          // 定义主要颜色和相关变量
          "primary": "hsl(210.34, 92.708%, 62.353%)", // 对应 --p
          "--pf": "210.34, 92.708%, 49.882%", // 对应 --pf
          "secondary": "hsl(141.89, 69.159%, 58.039%)", // 对应 --s
          "--sf": "141.89, 69.159%, 46.431%", // 对应 --sf
          "accent": "hsl(0, 0%, 0%)", // 对应 --af
          "neutral": "hsl(0, 0%, 13.333%)", // 对应 --n
          "base-100": "hsl(0, 0%, 96.471%)", // 对应 --b1
          "base-200": "hsl(210, 5.5556%, 92.941%)", // 对应 --b2
          "base-300": "hsl(210, 5.5556%, 83.647%)", // 对应 --b3
          "info": "hsl(208.57, 9.7674%, 57.843%)", // 对应 --in
          "success": "hsl(142.09, 70.563%, 45.294%)", // 对应 --su
          "warning": "hsl(43, 96%, 56%)", // 对应 --wa
          "error": "hsl(0, 90.541%, 70.98%)", // 对应 --er

          // 边框和圆角相关变量
          "--rounded-box": "1rem", // 对应 --rounded-box
          "--rounded-btn": "0.5rem", // 对应 --rounded-btn
          "--rounded-badge": "1.9rem", // 对应 --rounded-badge
          "--border-btn": "1px", // 对应 --border-btn
          "--tab-border": "1px", // 对应 --tab-border
          "--tab-radius": "0.5rem", // 对应 --tab-radius

          // 动画相关变量
          "--animation-btn": "0.25s", // 对应 --animation-btn
          "--animation-input": "0.2s", // 对应 --animation-input

          // 文本和焦点样式
          "--btn-text-case": "uppercase", // 对应 --btn-text-case
          "--btn-focus-scale": "0.95", // 对应 --btn-focus-scale
        },
      },
    ],
  },
};
export default config;
